to

# XMLRésuméLibrary: User Guide

title | Element Reference | uri

## Name

to — The ending point in a period of time

## Synopsis

### Content Model

    (date|present)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `to` element specifies the instant at which a given period of time ends. It is always preceeded by a `from` element in a `period`.

### Parents

`to` may be contained in these elements: `period`

## See Also

`from`.

## Examples

For examples, see `from` and `period`.

title | Element Reference | uri